# HGC
HydroGeoChemistry - A python package for correction, validation and analysis of ground water quality samples

.. image:: https://readthedocs.org/projects/hgc/badge/?version=latest&style=flat
                    :target: https://hgc.readthedocs.io
.. image:: https://img.shields.io/travis/KWR-Water/hgc
                    :target: https://travis-ci.com/KWR-Water/hgc
.. image:: https://img.shields.io/codecov/c/gh/KWR-Water/hgc
                    :target: https://codecov.io/gh/KWR-Water/hgc 
